CommandBar

Struct CommandBar 

pub struct CommandBar<'a, I: ApplicationInfo> { /* private fields */ }
Widget for rendering a command bar.

Implementations

Source

impl<'a, I> CommandBar<'a, I>
where I: ApplicationInfo,

pub fn new() -> Self

Create a new widget.

pub fn focus(self, focused: bool) -> Self

Indicate whether the widget is currently focused.

pub fn prompt_style(self, style: Style) -> Self

Set the style to use for the command bar’s prompt.

If one isn’t provided, then this is the same style specified with CommandBar::style.

pub fn style(self, style: Style) -> Self

Set the style to use for the contents of the inner TextBox.

pub fn status(self, msg: Option<Span<'a>>) -> Self

Set a status string that will be displayed instead of the contents when the widget is not currently focused.