ListCursor

Struct ListCursor 

pub struct ListCursor {
    pub position: usize,
    pub text_row: usize,
}
A position within a list.

Fields

position: usize

The position of the selected item within the list.

text_row: usize

A row within the Text representation of the selected ListItem.

Implementations

Source

impl ListCursor

pub fn new(position: usize, text_row: usize) -> Self

Create a new cursor for a list.