ListState

Struct ListState 

pub struct ListState<T, I>
where T: ListItem<I>, I: ApplicationInfo,
{ /* private fields */ }
Persistent state for List.

Implementations

Source

impl<T, I> ListState<T, I>
where T: ListItem<I>, I: ApplicationInfo,

pub fn new(id: I::ContentId, items: Vec<T>) -> Self

Create state for a list.

pub fn id(&self) -> I::ContentId

Get the content identifier for this list.

pub fn is_empty(&self) -> bool

Indicates whether or not this list contains any items.

pub fn len(&self) -> usize

Returns the number of items in this list.

pub fn set(&mut self, items: Vec<T>)

Replace the set of items with a new list.

pub fn get(&self) -> Option<&T>

Get a reference to the currently selected value.

pub fn get_mut(&mut self) -> Option<&mut T>

Get a mutable reference to the currently selected value.

pub fn set_term_info(&mut self, area: Rect)

Set the dimensions and placement within the terminal window for this list.