Screen

Struct Screen 

pub struct Screen<'a, W, I = EmptyInfo>
where W: Window<I>, I: ApplicationInfo,
{ /* private fields */ }
Widget for displaying a tabbed window layout with a command bar.

Implementations

Source

impl<'a, W, I> Screen<'a, W, I>
where W: Window<I>, I: ApplicationInfo,

pub fn new(store: &'a mut Store<I>) -> Self

Create a new widget.

pub fn border_style(self, style: Style) -> Self

What Style should be used when drawing borders.

pub fn border_style_focused(self, style: Style) -> Self

What Style should be used when drawing the border of the selected window.

pub fn border_type(self, border_type: BorderType) -> Self

What characters should be used when drawing borders.

pub fn borders(self, borders: bool) -> Self

Indicate whether to draw borders around windows.

pub fn cmdbar_style(self, style: Style) -> Self

What Style should be used when drawing borders.

pub fn cmdbar_prompt_style(self, style: Style) -> Self

What Style should be used when drawing the border of the selected window.

pub fn tab_style(self, style: Style) -> Self

What Style should be used for tab names.

pub fn tab_style_focused(self, style: Style) -> Self

What Style should be used for the focused tab name.

pub fn divider(self, divider: impl Into<Span<'a>>) -> Self

Set the divider Span to place in between tab names.

This defaults to an unstyled “|”.

pub fn focus(self, focused: bool) -> Self

Indicates whether the terminal window is currently focused.

pub fn show_dialog(self, dialog: Vec<Cow<'a, str>>) -> Self

Show the message from an interactive dialog.

pub fn show_mode(self, mode: Option<String>) -> Self

Set the mode string to display.