pub struct ScreenState<W, I = EmptyInfo>where
W: Window<I>,
I: ApplicationInfo,{ /* private fields */ }Expand description
Persistent state for Screen.
Implementations
Sourceimpl<W, I> ScreenState<W, I>where
W: Window<I>,
I: ApplicationInfo,
impl<W, I> ScreenState<W, I>where
W: Window<I>,
I: ApplicationInfo,
Sourcepub fn new(win: W, cmdbar: CommandBarState<I>) -> Self
pub fn new(win: W, cmdbar: CommandBarState<I>) -> Self
Create state for a Screen widget.
Sourcepub fn from_list(
tabs: FocusList<WindowLayoutState<W, I>>,
cmdbar: CommandBarState<I>,
) -> Self
pub fn from_list( tabs: FocusList<WindowLayoutState<W, I>>, cmdbar: CommandBarState<I>, ) -> Self
Create state for a Screen widget from an existing set of tabs.
Sourcepub fn as_description(&self) -> TabbedLayoutDescription<I>
pub fn as_description(&self) -> TabbedLayoutDescription<I>
Get a description of the open tabs and their window layouts.
Sourcepub fn push_message<T: ToString>(&mut self, msg: T, style: Style)
pub fn push_message<T: ToString>(&mut self, msg: T, style: Style)
Push a new error or status message.
Sourcepub fn push_error<T: ToString>(&mut self, msg: T)
pub fn push_error<T: ToString>(&mut self, msg: T)
Push an error message with a red foreground.
Sourcepub fn push_info<T: Into<String>>(&mut self, msg: T)
pub fn push_info<T: Into<String>>(&mut self, msg: T)
Push an info message with a default Style.
Sourcepub fn clear_message(&mut self)
pub fn clear_message(&mut self)
Clear the displayed error or status message.
Sourcepub fn command_bar(
&mut self,
act: &CommandBarAction<I>,
ctx: &EditContext,
) -> EditResult<EditInfo, I>
pub fn command_bar( &mut self, act: &CommandBarAction<I>, ctx: &EditContext, ) -> EditResult<EditInfo, I>
Perform a command bar action.
Sourcepub fn current_tab(&self) -> UIResult<&WindowLayoutState<W, I>, I>
pub fn current_tab(&self) -> UIResult<&WindowLayoutState<W, I>, I>
Get a reference to the window layout for the current tab.
Sourcepub fn current_tab_mut(&mut self) -> UIResult<&mut WindowLayoutState<W, I>, I>
pub fn current_tab_mut(&mut self) -> UIResult<&mut WindowLayoutState<W, I>, I>
Get a mutable reference to the window layout for the current tab.
Sourcepub fn current_window(&self) -> Option<&W>
pub fn current_window(&self) -> Option<&W>
Get a reference to the currently focused window.
Sourcepub fn current_window_mut(&mut self) -> UIResult<&mut W, I>
pub fn current_window_mut(&mut self) -> UIResult<&mut W, I>
Get a mutable reference to the currently focused window.