TextBox

Struct TextBox 

pub struct TextBox<'a, I: ApplicationInfo = EmptyInfo> { /* private fields */ }
Widget for rendering a multi-line text box.

Implementations

Source

impl<'a, I> TextBox<'a, I>
where I: ApplicationInfo,

pub fn new() -> Self

Create a new widget.

pub fn style(self, style: Style) -> Self

Set the style to use for rendering text within the TextBoxState.

pub fn block(self, block: Block<'a>) -> Self

Wrap this text box in a Block.

pub fn oneline(self) -> Self

Force the text to render on a single line. LF and CR will be rendered as ^J and ^M respectively.

Any gutters will not be shown.

pub fn prompt(self, prompt: impl Into<Span<'a>>) -> Self

Display a prompt in the top left of the text box when focused.

pub fn left_gutter(self, lw: u16) -> Self

Set the width of the left gutter.

pub fn right_gutter(self, rw: u16) -> Self

Set the width of the right gutter.