WindowLayout

Struct WindowLayout 

pub struct WindowLayout<'a, W: Window<I>, I: ApplicationInfo> { /* private fields */ }
Handles rendering the current window layout state to the terminal.

Implementations

Source

impl<'a, W, I> WindowLayout<'a, W, I>
where W: Window<I>, I: ApplicationInfo,

pub fn new(store: &'a mut Store<I>) -> Self

Create a new widget for displaying window layouts.

pub fn border_style(self, style: Style) -> Self

What Style should be used when drawing borders.

pub fn border_style_focused(self, style: Style) -> Self

What Style should be used when drawing the border of the selected window.

pub fn border_type(self, border_type: BorderType) -> Self

What characters should be used when drawing borders.

pub fn borders(self, borders: bool) -> Self

Indicate whether to draw borders around windows.

pub fn focus(self, focused: bool) -> Self

Indicate whether the window layout tree is currently focused.