WindowLayoutState

Struct WindowLayoutState 

pub struct WindowLayoutState<W: Window<I>, I: ApplicationInfo> { /* private fields */ }
Manages the current layout and focus of Windows on the screen.

Implementations

Source

impl<W, I> WindowLayoutState<W, I>
where W: Window<I>, I: ApplicationInfo,

pub fn new(window: W) -> Self

Create a new instance containing a single Window.

pub fn empty() -> Self

Create a new instance without any windows.

pub fn as_description(&self) -> WindowLayoutRoot<I>

Convert this layout to a serializable summary of its windows and splits.

pub fn from_target( &self, target: &OpenTarget<I::WindowId>, ctx: &EditContext, store: &mut Store<I>, ) -> UIResult<Self, I>

Create a new instance containing a single Window displaying some content.

pub fn get(&self) -> Option<&W>

Fetch a reference to the currently focused Window.

pub fn get_mut(&mut self) -> Option<&mut W>

Fetch a mutable reference the currently focused Window.

pub fn extract(&mut self) -> Self

Extract the currently focused Window into its own window layout.