pub struct CommandBar<'a, I: ApplicationInfo> { /* private fields */ }Expand description
Widget for rendering a command bar.
Implementations
Sourceimpl<'a, I> CommandBar<'a, I>where
I: ApplicationInfo,
impl<'a, I> CommandBar<'a, I>where
I: ApplicationInfo,
Sourcepub fn prompt_style(self, style: Style) -> Self
pub fn prompt_style(self, style: Style) -> Self
Set the style to use for the command bar’s prompt.
If one isn’t provided, then this is the same style specified with CommandBar::style.