pub struct Screen<'a, W, I = EmptyInfo>where
W: Window<I>,
I: ApplicationInfo,{ /* private fields */ }Expand description
Widget for displaying a tabbed window layout with a command bar.
Implementations
Sourceimpl<'a, W, I> Screen<'a, W, I>where
W: Window<I>,
I: ApplicationInfo,
impl<'a, W, I> Screen<'a, W, I>where
W: Window<I>,
I: ApplicationInfo,
Sourcepub fn border_style(self, style: Style) -> Self
pub fn border_style(self, style: Style) -> Self
What Style should be used when drawing borders.
Sourcepub fn border_style_focused(self, style: Style) -> Self
pub fn border_style_focused(self, style: Style) -> Self
What Style should be used when drawing the border of the selected window.
Sourcepub fn border_type(self, border_type: BorderType) -> Self
pub fn border_type(self, border_type: BorderType) -> Self
What characters should be used when drawing borders.
Sourcepub fn cmdbar_style(self, style: Style) -> Self
pub fn cmdbar_style(self, style: Style) -> Self
What Style should be used when drawing borders.
Sourcepub fn cmdbar_prompt_style(self, style: Style) -> Self
pub fn cmdbar_prompt_style(self, style: Style) -> Self
What Style should be used when drawing the border of the selected window.
Sourcepub fn tab_style_focused(self, style: Style) -> Self
pub fn tab_style_focused(self, style: Style) -> Self
What Style should be used for the focused tab name.
Sourcepub fn divider(self, divider: impl Into<Span<'a>>) -> Self
pub fn divider(self, divider: impl Into<Span<'a>>) -> Self
Set the divider Span to place in between tab names.
This defaults to an unstyled “|”.
Sourcepub fn focus(self, focused: bool) -> Self
pub fn focus(self, focused: bool) -> Self
Indicates whether the terminal window is currently focused.
Sourcepub fn show_dialog(self, dialog: Vec<Cow<'a, str>>) -> Self
pub fn show_dialog(self, dialog: Vec<Cow<'a, str>>) -> Self
Show the message from an interactive dialog.