ScreenState

Struct ScreenState 

pub struct ScreenState<W, I = EmptyInfo>
where W: Window<I>, I: ApplicationInfo,
{ /* private fields */ }
Persistent state for Screen.

Implementations

Source

impl<W, I> ScreenState<W, I>
where W: Window<I>, I: ApplicationInfo,

pub fn new(win: W, cmdbar: CommandBarState<I>) -> Self

Create state for a Screen widget.

pub fn from_list( tabs: FocusList<WindowLayoutState<W, I>>, cmdbar: CommandBarState<I>, ) -> Self

Create state for a Screen widget from an existing set of tabs.

pub fn as_description(&self) -> TabbedLayoutDescription<I>

Get a description of the open tabs and their window layouts.

pub fn push_message<T: ToString>(&mut self, msg: T, style: Style)

Push a new error or status message.

pub fn push_error<T: ToString>(&mut self, msg: T)

Push an error message with a red foreground.

pub fn push_info<T: Into<String>>(&mut self, msg: T)

Push an info message with a default Style.

pub fn clear_message(&mut self)

Clear the displayed error or status message.

pub fn command_bar( &mut self, act: &CommandBarAction<I>, ctx: &EditContext, ) -> EditResult<EditInfo, I>

Perform a command bar action.

pub fn current_tab(&self) -> UIResult<&WindowLayoutState<W, I>, I>

Get a reference to the window layout for the current tab.

pub fn current_tab_mut(&mut self) -> UIResult<&mut WindowLayoutState<W, I>, I>

Get a mutable reference to the window layout for the current tab.

pub fn current_window(&self) -> Option<&W>

Get a reference to the currently focused window.

pub fn current_window_mut(&mut self) -> UIResult<&mut W, I>

Get a mutable reference to the currently focused window.