pub struct TextBox<'a, I: ApplicationInfo = EmptyInfo> { /* private fields */ }Expand description
Widget for rendering a multi-line text box.
Implementations
Sourceimpl<'a, I> TextBox<'a, I>where
I: ApplicationInfo,
impl<'a, I> TextBox<'a, I>where
I: ApplicationInfo,
Sourcepub fn style(self, style: Style) -> Self
pub fn style(self, style: Style) -> Self
Set the style to use for rendering text within the TextBoxState.
Sourcepub fn oneline(self) -> Self
pub fn oneline(self) -> Self
Force the text to render on a single line. LF and CR will be rendered as ^J and ^M respectively.
Any gutters will not be shown.
Sourcepub fn prompt(self, prompt: impl Into<Span<'a>>) -> Self
pub fn prompt(self, prompt: impl Into<Span<'a>>) -> Self
Display a prompt in the top left of the text box when focused.
Sourcepub fn left_gutter(self, lw: u16) -> Self
pub fn left_gutter(self, lw: u16) -> Self
Set the width of the left gutter.
Sourcepub fn right_gutter(self, rw: u16) -> Self
pub fn right_gutter(self, rw: u16) -> Self
Set the width of the right gutter.