TextBoxState

Struct TextBoxState 

pub struct TextBoxState<I: ApplicationInfo = EmptyInfo> { /* private fields */ }
Persistent state for TextBox.

Implementations

Source

impl<I> TextBoxState<I>
where I: ApplicationInfo,

pub fn new(buffer: SharedBuffer<I>) -> Self

Create state for a new text box.

pub fn buffer(&self) -> SharedBuffer<I>

Get a reference to the shared buffer used by this text box.

pub fn is_readonly(&self) -> bool

Indicates whether the buffer contents are readonly.

pub fn set_readonly(&mut self, readonly: bool)

Set whether the buffer contents are modifiable through the Editable trait.

pub fn get(&self) -> EditRope

Get the contents of the underlying buffer as an EditRope.

pub fn get_text(&self) -> String

Get the contents of the underlying buffer as a String.

pub fn set_text<T: Into<EditRope>>(&mut self, t: T)

Replace the contents of the text box’s underlying buffer.

pub fn reset(&mut self) -> EditRope

Clear the text box’s underlying buffer of its content, and return it.

pub fn reset_text(&mut self) -> String

Clear the text box’s underlying buffer of its content, and return it as a String.

pub fn set_left_gutter(&mut self, line: usize, s: String, style: Option<Style>)

Create or update a line annotation for the left gutter.

pub fn set_right_gutter(&mut self, line: usize, s: String, style: Option<Style>)

Create or update a line annotation for the right gutter.

pub fn set_wrap(&mut self, wrap: bool)

Control whether the text box should wrap long lines when displaying them.

pub fn set_term_info(&mut self, area: Rect)

Inform the text box what its dimensions and placement on the terminal window is.

pub fn get_cursor(&mut self) -> Cursor

Get the leader cursor for this text box’s cursor group.

pub fn get_lines(&self) -> usize

Calculate how many lines are in this text box.

pub fn has_lines(&self, max: usize) -> usize

Check whether this text box is capable of displaying max lines.

If there are fewer lines available than max, this returns the same value as get_lines(). Otherwise, this returns max.

This method is useful for building additional widgets that want to create a TextBox with a flexible height up to max lines.