pub struct WindowLayoutState<W: Window<I>, I: ApplicationInfo> { /* private fields */ }Expand description
Manages the current layout and focus of Windows on the screen.
Implementations
Sourceimpl<W, I> WindowLayoutState<W, I>where
W: Window<I>,
I: ApplicationInfo,
impl<W, I> WindowLayoutState<W, I>where
W: Window<I>,
I: ApplicationInfo,
Sourcepub fn as_description(&self) -> WindowLayoutRoot<I>
pub fn as_description(&self) -> WindowLayoutRoot<I>
Convert this layout to a serializable summary of its windows and splits.
Sourcepub fn from_target(
&self,
target: &OpenTarget<I::WindowId>,
ctx: &EditContext,
store: &mut Store<I>,
) -> UIResult<Self, I>
pub fn from_target( &self, target: &OpenTarget<I::WindowId>, ctx: &EditContext, store: &mut Store<I>, ) -> UIResult<Self, I>
Create a new instance containing a single Window displaying some content.